==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/elements/prjshb.f <==
      SUBROUTINE PRJSHB(SSTAR,SELAS,PENTE,SI,DEPS,EPST,EPSTAR,ITER,SN,
     &     DHOOK,SIGEL,DSIGP,TEST,STOT,IMAT,ITMAX)
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ELEMENTS  DATE 08/03/2004   AUTEUR REZETTE C.REZETTE 
C ======================================================================
C COPYRIGHT (C) 1991 - 2003  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
C (AT YOUR OPTION) ANY LATER VERSION.                                   
C                                                                       
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
C                                                                       
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
C   1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.         
C ======================================================================
C TOLE CRP_21
C--------------------------------------------------------
C ELEMENT SHB8-PS A.COMBESCURE, S.BAGUET INSA LYON 2003 /   
C-------------------------------------------------------
CCCCCCCCCCCCC   PROJECTIONS EN AXES DE DEPART ELEMENT SHB8
C
      IMPLICIT REAL *8(A-H,O-Z)
      REAL*8 AM(36),A(36)
      REAL*8 DHOOK(36),SIGEL(6),DSIGP(6)
      REAL*8 W1(6),STOT(6)

C
CCCCCCCCC   REMPLISSAGE DE M SUIVANT LES PLASTICITE
C
C      CALL ZDANUL(AM,36)
      CALL R8INIR(36,0.D0,AM,1)
      DO 1010 IA=1,3
        AM((IA-1)*6+IA)=1.D0
        AM((IA-1)*6+21+IA)=1.5D0
 1010 CONTINUE
      AM(2)=-.5D0
      AM(3)=-.5D0
      AM(7)=-.5D0
      AM(9)=-.5D0
      AM(13)=-.5D0
      AM(14)=-.5D0
  200 CONTINUE
C
CCCCCCCCC  CALCUL DU 1ER DELTA EPSILON ETOILE
C
      ELT=SHUTAV(AM,SIGEL,DSIGP,6)
      ELT=ELT/SELAS
C
CCCCCCCCC  CALCUL DE M SIGMA
C
      CALL MULMAT(6,6,1,AM,SIGEL,W1)
      ELT1=SHUTAU(DHOOK,W1,6)
      DEPS=ELT/(PENTE+ELT1/(SELAS*SELAS))
      EPST=EPSTAR+DEPS

C
CCCCCCCCCC CALCUL DE D*M
C
      CALL MULMAT(6,6,6,DHOOK,AM,A)
      DEPSI=DEPS
      SI1=SSTAR
      PENTE1=PENTE
      ITER=0
C      CALL SHIFTD(SIGEL,SIGT,6)
      SI=SI1
      SN=SELAS
  555 CONTINUE
      ITER=ITER+1
CCCCCCCCCCC  CALCUL DE LA MATRICE A INVERSER
      JYCOMP=0
C      CALL SHIFTD(A,DHOOK,36)
      CALL R8COPY(36,A,1,DHOOK,1)
C      IF(ICINE.EQ.1) GO TO 2
C

       CALL RCTRAC(IMAT,'TRACTION','SIGM',0.D0,JPROLP,JVALEP,
     &                LCOURB,EM)

       CALL RCFONC('V','TRACTION',JPROLP,JVALEP,LCOURB,RBID,RBID,
     &                RBID,EPST,SN,PENTE1,AIRERP,RBID,RBID)
      
CCCCCCCCCCC CALCUL DE LA PENTE A LA FIN
C      CALL TRACTI(PENTE1,SN,EPST,SIG,EPS,NCOURB,LCOURB,1,TET,TREF,
C     1 IBI,LINCOU,TIMEXF,HPAS,DEPS)
C      IF(ICINE.EQ.2) SN=SN-EPST*PANTIN

    2 CONTINUE
      ELT=DEPS/SN
C      CALL AEQAX(DHOOK,ELT,36)
      DO 661 I=1,36
        DHOOK(I)=DHOOK(I)*ELT
661   CONTINUE
      JX=0
      DO 1 IA=1,6
        DHOOK(JX+IA)=DHOOK(JX+IA)+1.D0
        JX=JX+6
1     CONTINUE
      CALL RESNEQ(DHOOK,STOT,SIGEL,6)
C
CCCCCCCCC ON A RESOLU LE SYSTEME
C
      SI=VONMIS(SIGEL)
C
CCCCCCCCC SI EST IL EGAL A SN
C
      STST=ABS(SI-SN)/SN
      IF(STST.LE.TEST) GO TO 3
      IF(ITER.GT.ITMAX) GO TO 4
      X=PENTE1-(SI-SI1)/DEPSI
      DEPSI=(SI-SN)/X
      DEPS=DEPS+DEPSI
      IF(DEPS.LT.0.D0) GO TO 5
      SI1=SI
      EPST=EPSTAR+DEPS
      GO TO 555
    3 CONTINUE
C      IF(IBNSPL.NE.2) GO TO 7
C
CCCCCCCCC CALCUL DELA DEFORMATION PLASTIQUE ON LA MET DANS W1
C
C      IF(IDER.NE.1) GO TO 7
      CALL MULMAT(6,6,1,AM,SIGEL,W1)
      ELT=DEPS/SI
C      CALL AEQAX(W1,ELT,6)
       DO 556 I=1,6
         W1(I)=W1(I)*ELT
556    CONTINUE
    7 CONTINUE
      GOTO 9999
    4 CONTINUE
C      NBMSG=NBMSG+1
C      IF(NBMSG.LT.ITMAX)WRITE(6,1000) ITMAX,IPOIN,STST
C 1000 FORMAT(/,1X,' NOMBRE D ITERATIONS INTERNES ',I2,
C     1 'POINT',I2,' TEST ',1PE10.3)
      GO TO 3
    5 CONTINUE
C
CCCCCCCCCC, DEPS NEGATIF
C
      DEPSI=0.5D0*DEPSI
      DEPS=DEPS-DEPSI
      JYCOMP=JYCOMP+1
      IF(JYCOMP.GT.ITMAX) GO TO 4
      IF(DEPS.LT.0.D0) GO TO 5
      GO TO 555
9999  CONTINUE
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/elements/prjshb.f <==
      SUBROUTINE PRJSHB(SSTAR,SELAS,PENTE,SI,DEPS,EPST,EPSTAR,ITER,SN,
     &     DHOOK,SIGEL,DSIGP,TEST,STOT,IMAT,ITMAX)
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ELEMENTS  DATE 16/12/2004   AUTEUR VABHHTS J.PELLET 
C ======================================================================
C COPYRIGHT (C) 1991 - 2003  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
C (AT YOUR OPTION) ANY LATER VERSION.                                   
C                                                                       
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
C                                                                       
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
C   1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.         
C ======================================================================
C TOLE CRP_21
C--------------------------------------------------------
C ELEMENT SHB8-PS A.COMBESCURE, S.BAGUET INSA LYON 2003 /   
C-------------------------------------------------------
CCCCCCCCCCCCC   PROJECTIONS EN AXES DE DEPART ELEMENT SHB8
C
      IMPLICIT REAL *8(A-H,O-Z)
      REAL*8 AM(36),A(36)
      REAL*8 DHOOK(36),SIGEL(6),DSIGP(6)
      REAL*8 W1(6),STOT(6)

C
CCCCCCCCC   REMPLISSAGE DE M SUIVANT LES PLASTICITE
C
C      CALL ZDANUL(AM,36)
      CALL R8INIR(36,0.D0,AM,1)
      DO 1010 IA=1,3
        AM((IA-1)*6+IA)=1.D0
        AM((IA-1)*6+21+IA)=1.5D0
 1010 CONTINUE
      AM(2)=-.5D0
      AM(3)=-.5D0
      AM(7)=-.5D0
      AM(9)=-.5D0
      AM(13)=-.5D0
      AM(14)=-.5D0
  200 CONTINUE
C
CCCCCCCCC  CALCUL DU 1ER DELTA EPSILON ETOILE
C
      ELT=SHUTAV(AM,SIGEL,DSIGP,6)
      ELT=ELT/SELAS
C
CCCCCCCCC  CALCUL DE M SIGMA
C
      CALL MULMAT(6,6,1,AM,SIGEL,W1)
      ELT1=SHUTAU(DHOOK,W1,6)
      DEPS=ELT/(PENTE+ELT1/(SELAS*SELAS))
      EPST=EPSTAR+DEPS

C
CCCCCCCCCC CALCUL DE D*M
C
      CALL MULMAT(6,6,6,DHOOK,AM,A)
      DEPSI=DEPS
      SI1=SSTAR
      PENTE1=PENTE
      ITER=0
C      CALL SHIFTD(SIGEL,SIGT,6)
      SI=SI1
      SN=SELAS
  555 CONTINUE
      ITER=ITER+1
CCCCCCCCCCC  CALCUL DE LA MATRICE A INVERSER
      JYCOMP=0
C      CALL SHIFTD(A,DHOOK,36)
      CALL DCOPY(36,A,1,DHOOK,1)
C      IF(ICINE.EQ.1) GO TO 2
C

       CALL RCTRAC(IMAT,'TRACTION','SIGM',0.D0,JPROLP,JVALEP,
     &                LCOURB,EM)

       CALL RCFONC('V','TRACTION',JPROLP,JVALEP,LCOURB,RBID,RBID,
     &                RBID,EPST,SN,PENTE1,AIRERP,RBID,RBID)
      
CCCCCCCCCCC CALCUL DE LA PENTE A LA FIN
C      CALL TRACTI(PENTE1,SN,EPST,SIG,EPS,NCOURB,LCOURB,1,TET,TREF,
C     1 IBI,LINCOU,TIMEXF,HPAS,DEPS)
C      IF(ICINE.EQ.2) SN=SN-EPST*PANTIN

    2 CONTINUE
      ELT=DEPS/SN
C      CALL AEQAX(DHOOK,ELT,36)
      DO 661 I=1,36
        DHOOK(I)=DHOOK(I)*ELT
661   CONTINUE
      JX=0
      DO 1 IA=1,6
        DHOOK(JX+IA)=DHOOK(JX+IA)+1.D0
        JX=JX+6
1     CONTINUE
      CALL RESNEQ(DHOOK,STOT,SIGEL,6)
C
CCCCCCCCC ON A RESOLU LE SYSTEME
C
      SI=VONMIS(SIGEL)
C
CCCCCCCCC SI EST IL EGAL A SN
C
      STST=ABS(SI-SN)/SN
      IF(STST.LE.TEST) GO TO 3
      IF(ITER.GT.ITMAX) GO TO 4
      X=PENTE1-(SI-SI1)/DEPSI
      DEPSI=(SI-SN)/X
      DEPS=DEPS+DEPSI
      IF(DEPS.LT.0.D0) GO TO 5
      SI1=SI
      EPST=EPSTAR+DEPS
      GO TO 555
    3 CONTINUE
C      IF(IBNSPL.NE.2) GO TO 7
C
CCCCCCCCC CALCUL DELA DEFORMATION PLASTIQUE ON LA MET DANS W1
C
C      IF(IDER.NE.1) GO TO 7
      CALL MULMAT(6,6,1,AM,SIGEL,W1)
      ELT=DEPS/SI
C      CALL AEQAX(W1,ELT,6)
       DO 556 I=1,6
         W1(I)=W1(I)*ELT
556    CONTINUE
    7 CONTINUE
      GOTO 9999
    4 CONTINUE
C      NBMSG=NBMSG+1
C      IF(NBMSG.LT.ITMAX)WRITE(6,1000) ITMAX,IPOIN,STST
C 1000 FORMAT(/,1X,' NOMBRE D ITERATIONS INTERNES ',I2,
C     1 'POINT',I2,' TEST ',1PE10.3)
      GO TO 3
    5 CONTINUE
C
CCCCCCCCCC, DEPS NEGATIF
C
      DEPSI=0.5D0*DEPSI
      DEPS=DEPS-DEPSI
      JYCOMP=JYCOMP+1
      IF(JYCOMP.GT.ITMAX) GO TO 4
      IF(DEPS.LT.0.D0) GO TO 5
      GO TO 555
9999  CONTINUE
      END
